==> huaweicloudsdkcoc-3.1.120-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_authorizable_tickets_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuthorizableTicketsReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_params': 'list[AuthorizableTicketBody]'
    }

    attribute_map = {
        'request_params': 'request_params'
    }

    def __init__(self, request_params=None):
        """ListAuthorizableTicketsReq

        The model defined in huaweicloud sdk

        :param request_params: 搜索结果
        :type request_params: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        
        

        self._request_params = None
        self.discriminator = None

        if request_params is not None:
            self.request_params = request_params

    @property
    def request_params(self):
        """Gets the request_params of this ListAuthorizableTicketsReq.

        搜索结果

        :return: The request_params of this ListAuthorizableTicketsReq.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        return self._request_params

    @request_params.setter
    def request_params(self, request_params):
        """Sets the request_params of this ListAuthorizableTicketsReq.

        搜索结果

        :param request_params: The request_params of this ListAuthorizableTicketsReq.
        :type request_params: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        self._request_params = request_params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuthorizableTicketsReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.154-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/list_authorizable_tickets_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuthorizableTicketsReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_params': 'list[AuthorizableTicketBody]'
    }

    attribute_map = {
        'request_params': 'request_params'
    }

    def __init__(self, request_params=None):
        r"""ListAuthorizableTicketsReq

        The model defined in huaweicloud sdk

        :param request_params: 搜索结果
        :type request_params: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        
        

        self._request_params = None
        self.discriminator = None

        if request_params is not None:
            self.request_params = request_params

    @property
    def request_params(self):
        r"""Gets the request_params of this ListAuthorizableTicketsReq.

        搜索结果

        :return: The request_params of this ListAuthorizableTicketsReq.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        return self._request_params

    @request_params.setter
    def request_params(self, request_params):
        r"""Sets the request_params of this ListAuthorizableTicketsReq.

        搜索结果

        :param request_params: The request_params of this ListAuthorizableTicketsReq.
        :type request_params: list[:class:`huaweicloudsdkcoc.v1.AuthorizableTicketBody`]
        """
        self._request_params = request_params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuthorizableTicketsReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
